@@ -1,13 +1,12 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2018-11-23 17:43:57 mtw>
+# Last changed Time-stamp: <2017-06-08 19:16:16 michl>
 
 package Bio::ViennaNGS::Subtypes;
 
-use Bio::ViennaNGS;
+use version; our $VERSION = qv('0.17');
 use Moose::Util::TypeConstraints;
 use Bio::DB::Fasta;
 use Params::Coerce ();
-use version; our $VERSION = version->declare("$Bio::ViennaNGS::VERSION");
 
 subtype 'Bio::ViennaNGS::MyFasta' => as class_type('Bio::DB::Fasta');
 
@@ -20,9 +19,4 @@ coerce 'Bio::ViennaNGS::MyFasta'
 subtype 'Bio::ViennaNGS::PlusOrMinus',
   as 'Str',
   where { /[\+\-\.]/ },
-  message { "[SUBTYPE ISSUE]: expecting '+','-', or '.', however ($_) is neither."};
-
-subtype 'Bio::ViennaNGS::ZeroOrOne',
-  as 'Int',
-  where { $_ == 0 or $_ == 1 },
-  message { "[SUBTYPE ISSUE]: expecting '0' or '1', however ($_) is neither." };
+  message { "$_ is neither +/- nor ."};
