@@ -1,10 +1,10 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-10-27 14:44:46 mtw>
+# Last changed Time-stamp: <2017-06-08 19:18:24 michl>
 
 package Bio::ViennaNGS::Util;
 
 use Exporter;
-use version; our $VERSION = qv('0.16');
+use version; our $VERSION = qv('0.17');
 use strict;
 use warnings;
 use Data::Dumper;
@@ -14,14 +14,13 @@ use Path::Class qw(dir file);
 use File::Path qw(make_path remove_tree);
 use Math::Round;
 use Carp;
-use Bio::ViennaNGS::FeatureChain;
+use Env qw(HOME);
 
 our @ISA = qw(Exporter);
 our @EXPORT = ();
 
 our @EXPORT_OK = qw ( bed_or_bam2bw sortbed bed2bigBed unique_array
-		      kmer_enrichment extend_chain parse_bed6
-		      fetch_chrom_sizes mkdircheck rmdircheck);
+		      kmer_enrichment fetch_chrom_sizes mkdircheck rmdircheck);
 
 
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
@@ -228,123 +227,6 @@ sub kmer_enrichment{
     return( \%km );
 }
 
-sub extend_chain{
-  my %sizes = %{$_[0]};
-  my $chain = $_[1];
-  my $l	    = $_[2];
-  my $r	    = $_[3];
-  my $u     = $_[4];
-  my $d     = $_[5];
-  my $e     = $_[6];
-  my $this_function = (caller(0))[3];
-
-  ##return a new chain with extended coordinates
-  my $extendchain = $chain -> clone();
-  ## got through all features in original chain, calculate new start and end and safe in extendchain
-  my @featarray = @{$extendchain->chain};
-  foreach my $feature (@featarray){
-    my $chrom  = $feature->chromosome;
-    my $start  = $feature->start;
-    my $end    = $feature->end;
-    my $strand = $feature->strand;
-    my $right  = 0;
-    my $left   = 0;
-    my $width  = nearest(1,($end-$start)/2);
-    $width = 0 if ($d > 0 || $u > 0 || !$e);
-    if ($strand eq "+"){
-      if ($d > 0){
-	$start = $end;
-	$r = $d;
-      }
-      if ($u > 0){
-	$end = $start;
-	$l = $u;
-      }
-      $right=$r;
-      $left=$l;
-    }
-    elsif ($strand eq "-"){
-      if ($u > 0){
-	$start = $end;
-	$l = $u;
-      }
-      if ($d > 0){
-	$end = $start;
-	$r = $d;
-      }
-      $right=$l;
-      $left=$r;
-    }
-    if (($right-$width) <= 0){
-      $right = 0;
-    }
-    else{
-      $right-=$width;
-    }
-    if (($left-$width) <= 0 ){
-      $left = 0;
-    }
-    else{
-      $left-=$width;
-    }
-    if ( $start-$left >= 1 ){
-      if ($end+$right >= $sizes{"chr".$chrom}){
-	$end = $sizes{"chr".$chrom};
-      }
-      else{
-	$end += $right;
-      }
-      $start -= $left;
-    }
-    elsif ( $start-$left <= 0 ){
-      $start = 0;
-      if ($end+$right >= $sizes{"chr".$chrom}){
-	$end = $sizes{"chr".$chrom};
-      }
-      else{
-	$end = $end+$right;
-      }
-    }
-    else{
-      croak "ERROR [$this_function] Something wrong here!\n";
-    }
-    $feature->start($start);
-    $feature->end($end);
-  }
-  $extendchain->type('extended');
-  return($extendchain);
-}
-
-sub parse_bed6{
-  my $bedfile = shift;
-  my $this_function = (caller(0))[3];
-  open (my $Bed, "<:gzip(autopop)",$bedfile) or 
-    croak "ERROR [$this_function] $!";
-  my @featurelist; ## This will become a FeatureChain
-  while(<$Bed>){
-    ### This should be done by FeatureIO
-    chomp (my $raw = $_);
-    push my @line , split (/\t/,$raw);
-    push @line, "\." if ( !$line[5] ); 
-
-    (my $chromosome  = $line[0])=~ s/chr//g;
-    my $start	     = $line[1];
-    my $end	     = $line[2];
-    my $name	     = $line[3];
-    my $score	     = $line[4];
-    my $strand	     = $line[5];
-
-    my $feat = Bio::ViennaNGS::Feature->new(chromosome=>$chromosome,
-					    start=>$start,
-					    end=>$end,
-					    name=>$name,
-					    score=>$score,
-					    strand=>$strand);
-    push @featurelist, $feat;
-  }
-  return (\@featurelist);
-}
-
 sub fetch_chrom_sizes{
   my $species = shift;
   my %sizes;
@@ -397,6 +279,10 @@ sub mkdircheck {
   }
   foreach (@dirstocreate){
     my @total = split(/[\/\\]/,$_);
+    if ($total[0] eq '~'){
+      $total[0]=$HOME;
+      carp "WARNING [$this_function] replacing \'~\' in path with \'$HOME\'";
+    }
     my $dir;
     while(@total){
       $dir = dir(shift(@total)) unless (defined $dir);
@@ -539,24 +425,6 @@ kmer. Counts occurences of kmers of given length and returns a
 reference to a hash containing the kmer as key and occurences as
 value.
 
-=item extend_chain($chromsizes,$chain,$left,$right,$upstream,$downstream,$extension)
-
-Takes a hash containing chromosomes and their corresponding sizes, as
-e.g. returned by the L<fetch_chrom_sizes> method. Second argument is a
-chain as generated by L<parse_bed6>.
-
-This chain is then either extended to the desired minimal size, extend
-from either the 5' and/or 3' end of the chain or returns only the 5'
-or 3' extended region plus an optional extension into the existing
-chain.
-
-=item parse_bed6($bedfile)
-
-Takes a path to a bed6 file optionally containing additional fields
-and returns a reference to an array of L<ViennaNGS::Feature>
-objects. This array can then easily be used for creation of an
-L<ViennaNGS::FeatureChain> object.
-
 =item fetch_chrom_sizes($species)
 
 Takes the name of the desired species (e.g. hg19, mm9, ..) and
@@ -582,8 +450,6 @@ specific path and removes directories.
 
 =over
 
-=item L<Bio::ViennaNGS::FeatureChain>
-
 =item L<Bio::Perl> >= 1.00690001
 
 =item L<File::Basename>
@@ -623,7 +489,7 @@ Examples for using most of the provided methods can be found at L<ViennaNGS::Tut
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
+Copyright (C) 2015-2017 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
